@@ -6,17 +6,14 @@ import platform
 import sys
 import tempfile
 
-import responses
-
 import siaskynet as skynet
 
 
-SKYLINK = "XABvi7JtJbQSMAcDwnUnmp2FKDPjg8_tTTFP4BwMSxVdEg"
+SKYLINK = "AAA9s0sR9i8NGy19EadRGcpUt0HdvDMHJilKGmW545-k1g"
 
 client = skynet.SkynetClient()
 
 
-@responses.activate
 def test_download_file():
     """Test downloading a file to a temporary location."""
 
@@ -26,14 +23,7 @@ def test_download_file():
 
     src_file = "./testdata/file1"
 
-    # download a file
-
-    responses.add(
-        responses.GET,
-        'https://siasky.net/'+SKYLINK,
-        "test\n",
-        status=200
-    )
+    # Download a file.
 
     dst_file = tempfile.NamedTemporaryFile().name
     print("Downloading to "+dst_file)
@@ -44,4 +34,25 @@ def test_download_file():
 
     print("File download successful")
 
-    assert len(responses.calls) == 1
+
+def test_get_metadata():
+    """Test downloading the metadata for a file."""
+
+    expected_metadata = {
+        'filename': 'file1',
+        'length': 5,
+        'subfiles': {
+            'file1': {
+                'filename': 'file1',
+                'contenttype': 'application/octet-stream',
+                'len': 5
+            }
+        }
+    }
+
+    # Download a file's metadata.
+
+    metadata = client.get_metadata(SKYLINK)
+    if metadata != expected_metadata:
+        sys.exit("ERROR: Downloaded metadata "+str(metadata) +
+                 " did not equal expected metadata "+str(expected_metadata))
